<?php
/**
 * @file
 * Contains \Drupal\inspect\Controller\InspectAjaxController.
 */

namespace Drupal\inspect\Controller;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;

use Drupal\inspect\Inspect;

/**
 * Defines a controller to log from frontend (Javascript) inspect.
 */
class InspectAjaxController {

  /**
   * @throws \Symfony\Component\HttpKernel\Exception\BadRequestHttpException
   * @throws \Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   */
  public function logFromFrontend(Request $request) {
    // Don't respond if $_POST is empty, because SimpleComplex\Inspect listens
    // to $_POST directly - it is not symfony'c.
    if (empty($_POST)) {
      throw new BadRequestHttpException();
    }

    // The path parameters - {sessionCounter}/{logNo}/{severity} - aren't
    // available. Or things have to be done in some other way, to get them.
    // But they are available in $_POST/request body by (inspect frontend's)
    // design anyway.
    // So let's play by the book and retrieve them from Symfony's Request body.
    if (!empty($request->request)
      && ($sessionCounter = $request->request->get('sessionCounter'))
      && ($logNo = $request->request->get('logNo'))
      && ($severity = $request->request->get('severity'))
    ) {
      // \SimpleComplex\Inspect::logFromFrontend() performs strict validation
      // of all parameters, so there's no need doing that here.
      Inspect::logFromFrontend($sessionCounter, $logNo, $severity);
    }

    throw new AccessDeniedHttpException();
  }

}
